@@ -5,10 +5,11 @@
 #' retrieved.
 #' 
 #' @param file character string.
-#' @param date a \code{POSIXct} object, but if \code{NULL} the date stored in 
-#'   file header is used, and if \code{NA} the "when.measured" attribute is not
-#'   set.
-#' @param geocode A data frame with columns \code{lon} and \code{lat}.
+#' @param date a \code{POSIXct} object to use to set the \code{"when.measured"}
+#'   attribute. If \code{NULL}, the default, the date is extracted from the
+#'   file header.
+#' @param geocode A data frame with columns \code{lon} and \code{lat} used to
+#'   set attribute \code{"where.measured"}.
 #' @param label character string, but if \code{NULL} the value of \code{file} is
 #'   used, and if \code{NA} the "what.measured" attribute is not set.
 #' @param tz character Time zone used for interpreting times saved in the file
@@ -37,7 +38,12 @@ read_oo_jazirrad <- function(file,
     tz <- locale$tz
   }
   
-  label <- paste("File:", basename(file), label)
+  label.file <- paste("File: ", basename(file), sep = "")
+  if (is.null(label)) {
+    label <- label.file
+  } else if (!is.na(label)) {
+    label <- paste(label.file, label, sep = "\n")
+  }
   
   line01 <-
     scan(
@@ -96,9 +102,10 @@ read_oo_jazirrad <- function(file,
                 lubridate::now(tzone = "UTC"), " UTC", sep = ""),
           paste(file_header, collapse = "\n"), 
           sep = "\n")
-    photobiology::setWhenMeasured(z, date)
-    photobiology::setWhereMeasured(z, geocode)
-    photobiology::setWhatMeasured(z, label)
+  photobiology::setWhenMeasured(z, date)
+  photobiology::setWhereMeasured(z, geocode)
+  photobiology::setWhatMeasured(z, label)
+  attr(z, "file.header") <- file_header
   z
 }
 
@@ -116,7 +123,12 @@ read_oo_jazdata <- function(file,
     tz <- locale$tz
   }
   
-  label <- paste("File:", basename(file), label)
+  label.file <- paste("File: ", basename(file), sep = "")
+  if (is.null(label)) {
+    label <- label.file
+  } else {
+    label <- paste(label.file, label, sep = "\n")
+  }
   
   line01 <-
     scan(
@@ -228,6 +240,6 @@ read_oo_jazdata <- function(file,
   photobiology::setWhenMeasured(z, date)
   photobiology::setWhereMeasured(z, geocode)
   photobiology::setWhatMeasured(z, label)
-  attr(z, "file.header", file_header)
+  attr(z, "file.header") <- file_header
   z
 }
