@@ -5,9 +5,11 @@
 #'
 #' @param file character string
 #' @param ozone.du numeric Ozone column in Dobson units.
-#' @param date a \code{POSIXct} object, but if \code{NULL} the date stored in
-#'   file is used, and if \code{NA} no date variable is added
-#' @param geocode A data frame with columns \code{lon} and \code{lat}.
+#' @param date a \code{POSIXct} object to use to set the \code{"when.measured"}
+#'   attribute. If \code{NULL}, the default, the date is extracted from the
+#'   file header.
+#' @param geocode A data frame with columns \code{lon} and \code{lat} used to
+#'   set attribute \code{"where.measured"}.
 #' @param label character string, but if \code{NULL} the value of \code{file} is
 #'   used, and if \code{NA} the "what.measured" attribute is not set.
 #' @param tz character Time zone is by default read from the file.
@@ -42,7 +44,13 @@ read_tuv_usrout <- function(file,
   if (is.null(geocode)) {
     geocode <- tibble::tibble(lon = NA_real_, lat = NA_real_)
   }
-  label <- paste("File:", basename(file), label)
+
+  label.file <- paste("File: ", basename(file), sep = "")
+  if (is.null(label)) {
+    label <- label.file
+  } else if (!is.na(label)) {
+    label <- paste(label.file, label, sep = "\n")
+  }
   
   file_header <- scan(file = file, nlines = 5, what = "character", sep = "\n" )
   hours <- scan(text = sub(pattern = "wc, nm", replacement = "",
@@ -80,7 +88,7 @@ read_tuv_usrout <- function(file,
   photobiology::setWhatMeasured(z, paste("TUV spectral simulation", label))
   photobiology::setWhereMeasured(z, geocode)
   photobiology::setWhenMeasured(z, unique(z[["date"]]))
-  attr(z, "file.header", file_header)
+  attr(z, "file.header") <- file_header
   z
 }
 
@@ -147,10 +155,16 @@ read_qtuv_txt <- function(file,
     tz <- locale[["tz"]]
   }
   
-  label <- paste("File:", basename(file), label)
+  label.file <- paste("File: ", basename(file), sep = "")
+  if (is.null(label)) {
+    label <- label.file
+  } else if (!is.na(label)) {
+    label <- paste(label.file, label, sep = "\n")
+  }
   
   # make sure we read whole header even is garbage present
   file_header <- readr::read_lines(file = file, n_max = 100L)
+  
   # find top of header
   header.start.idx <- grep("INPUT PARAMETERS:", file_header, fixed = TRUE)
   if (!length(header.start.idx)) {
@@ -172,21 +186,28 @@ read_qtuv_txt <- function(file,
   # trim garbage above and below header
   file_header <- file_header[header.start.idx:header.end.idx]
 
-  # find length of spectral data
-  grid.line.idx <- grep("w-grid:", file_header, fixed = TRUE)
+  # read wavelength grid data
+  wgrid.line.idx <- grep("w-grid:", file_header, fixed = TRUE)
   temp <-
-    scan(text = file_header[grid.line.idx], 
-         what = list(NULL, length = 1L, wl.min = 1, wl.maX = 1))
+    scan(text = file_header[wgrid.line.idx], 
+         what = list(NULL, length = 1L, wl.min = 1, wl.max = 1))
   length.spct <- temp[["length"]] - 1L # number of wl intervals
   wl.min = temp[["wl.min"]]
   wl.max = temp[["wl.max"]]
-  # decode metadata
+  
+  # read vertical grid data
+  zgrid.line.idx <- grep("z-grid:", file_header, fixed = TRUE)
+  temp <-
+    scan(text = file_header[zgrid.line.idx], 
+         what = list(NULL, NULL, z.min = 1, z.max = 1))
+  observer.km.asl <- temp["z.min"]
+
   # read date
   date.line <- grep("idate =", file_header)
   temp <- scan(text = file_header[date.line],
                     what = list(NULL, NULL, idate = "", NULL, NULL, esfact = 1))
   date <- lubridate::ymd(temp[["idate"]])
-  esfact <- temp[["esfact"]]
+#  esfact <- temp[["esfact"]]
   
   # "solar zenith angle = " -> angle. Always present either user supplied or calculated
   zenith.angle.line <- file_header[grepl("solar zenith angle", file_header)]
@@ -198,9 +219,9 @@ read_qtuv_txt <- function(file,
     scan(text = sub("measurement point: ", "", altitude.line, fixed = TRUE),
        what = list(NULL, index = 1, NULL, alt = 1))
     )
-  ground.elevation <- temp["alt"]
-  observer.above.ground <- temp["index"]
-  # " lat=    0.000000      long=    0.000000      ut=    12.00000    ". 
+  ground.km.asl <- temp["alt"]
+
+    # " lat=    0.000000      long=    0.000000      ut=    12.00000    ". 
   # Present for option 1 (user supplied location and time)
   geocode.line <- file_header[grepl("lat=", file_header)]
   if (length(geocode.line)) {
@@ -226,6 +247,7 @@ read_qtuv_txt <- function(file,
     lubridate::minute(date) <- trunc(minutes)
     lubridate::second(date) <- trunc(seconds)
   }
+  
   # assemple comment
   comment.txt <- paste(gsub(":", "", data.header.line), "\n",
                        "from file: ", file, 
@@ -233,8 +255,8 @@ read_qtuv_txt <- function(file,
                        file.info(file)[["ctime"]],
                        "ozone column (DU) = ", ozone.du, "\n",
                        "zenith angle (degrees) = ", zenith.angle, "\n",
-                       "altitude (km)  = ", ground.elevation, "\n",
-                       "observer elev. = ", observer.above.ground)
+                       "altitude (km)  = ", ground.km.asl, "\n",
+                       "observer elev. = ", observer.km.asl)
   
   # read spectrum
   spct.tb <-
@@ -246,6 +268,7 @@ read_qtuv_txt <- function(file,
                                      "s.e.irrad"),
                        n_max = length.spct)
   spct.tb <- stats::na.omit(spct.tb)
+  # convert to spectrum object
   z <-
     photobiology::source_spct(w.length = (spct.tb[["w.length.s"]] + spct.tb[["w.length.l"]]) / 2,
                               s.e.irrad = spct.tb[["s.e.irrad"]],
@@ -255,10 +278,12 @@ read_qtuv_txt <- function(file,
                               angle = zenith.angle,
                               date = rep(as.POSIXct(date), nrow(spct.tb)),
                               comment = comment.txt)
+  
+  # add metadata
   photobiology::setWhatMeasured(z, paste("Quick TUV spectral simulation", label))
   photobiology::setWhenMeasured(z, date)
   photobiology::setWhereMeasured(z, geocode)
-  attr(z, "file.header", file_header)
+  attr(z, "file.header") <- file_header
   z
 }
   
